pub struct Boolean(/* private fields */);Expand description
A simple Boolean type that reads and writes as a single byte.
Any non-zero value is considered true, as defined by MS-FSCC 2.1.8.
Similar to the WinAPI BOOL type.
This type supports std::size_of::<Boolean>() == 1, ensuring it is 1 byte in size.