pub struct BaseFixedString<C, const N: usize>where
C: BinRead + BinWrite + Copy + Clone + Default + 'static + Sized,
for<'a> <C as BinRead>::Args<'a>: Default + Clone,
for<'b> <C as BinWrite>::Args<'b>: Default + Clone,{ /* private fields */ }Expand description
Fixed-size string with a specified character type and length.
The string always takes up exactly N characters, with unused characters filled with default values of the character type.
Notes:
From<&str>trims or pads the string to fit exactly N characters.TryInto<String>only pads with default values, it does not trim.
Implementations
Sourceimpl<C, const N: usize> BaseFixedString<C, N>
impl<C, const N: usize> BaseFixedString<C, N>
Sourcepub const SIZE_BYTES: usize
pub const SIZE_BYTES: usize
The size of the FixedString in memory, in bytes.
This is also it’s size when bin-read or bin-written.
Sourcepub const MAX_CHARS: usize = N
pub const MAX_CHARS: usize = N
The maximum number of characters in the FixedString.
This is the very same as the generic const parameter N.
Sourcepub fn from_slice(slice: &[C]) -> Self
pub fn from_slice(slice: &[C]) -> Self
Creates a new FixedString from a slice.
If the slice is shorter than N, the remaining bytes are filled with default values. If the slice is longer than N, it is truncated.