pub struct AccessMask { /* private fields */ }Expand description
This struct was partially generated by the smb_dtyp::access_mask! macro.
Read more about generic access rights
and standard access rights
Implementations
Sourceimpl AccessMask
impl AccessMask
Sourceimpl AccessMask
impl AccessMask
Sourcepub const fn into_bytes(self) -> [u8; 4]
pub const fn into_bytes(self) -> [u8; 4]
Sourcepub const fn from_bytes(bytes: [u8; 4]) -> Self
pub const fn from_bytes(bytes: [u8; 4]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl AccessMask
impl AccessMask
Sourcepub fn common_or_err(
&self,
) -> Result<<B16 as Specifier>::InOut, InvalidBitPattern<<B16 as Specifier>::Bytes>>
pub fn common_or_err( &self, ) -> Result<<B16 as Specifier>::InOut, InvalidBitPattern<<B16 as Specifier>::Bytes>>
Returns the value of common.
#Errors
If the returned value contains an invalid bit pattern for common.
Sourcepub fn with_common(self, new_val: <B16 as Specifier>::InOut) -> Self
pub fn with_common(self, new_val: <B16 as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of common set to the given value.
#Panics
If the given value is out of bounds for common.
Sourcepub fn with_common_checked(
self,
new_val: <B16 as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_common_checked( self, new_val: <B16 as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of common set to the given value.
#Errors
If the given value is out of bounds for common.
Sourcepub fn set_common(&mut self, new_val: <B16 as Specifier>::InOut)
pub fn set_common(&mut self, new_val: <B16 as Specifier>::InOut)
Sets the value of common to the given value.
#Panics
If the given value is out of bounds for common.
Sourcepub fn set_common_checked(
&mut self,
new_val: <B16 as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_common_checked( &mut self, new_val: <B16 as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of common to the given value.
#Errors
If the given value is out of bounds for common.
Sourcepub fn delete(&self) -> <bool as Specifier>::InOut
pub fn delete(&self) -> <bool as Specifier>::InOut
Returns the value of delete. (std) The right to delete the object.
Sourcepub fn delete_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn delete_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of delete.
#Errors
If the returned value contains an invalid bit pattern for delete. (std) The right to delete the object.
Sourcepub fn with_delete(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_delete(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of delete set to the given value.
#Panics
If the given value is out of bounds for delete. (std) The right to delete the object.
Sourcepub fn with_delete_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_delete_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of delete set to the given value.
#Errors
If the given value is out of bounds for delete. (std) The right to delete the object.
Sourcepub fn set_delete(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_delete(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of delete to the given value.
#Panics
If the given value is out of bounds for delete. (std) The right to delete the object.
Sourcepub fn set_delete_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_delete_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of delete to the given value.
#Errors
If the given value is out of bounds for delete. (std) The right to delete the object.
Sourcepub fn read_control(&self) -> <bool as Specifier>::InOut
pub fn read_control(&self) -> <bool as Specifier>::InOut
Returns the value of read_control. (std) The right to read the information in the object’s security descriptor, not including the information in the system access control list (SACL).
Sourcepub fn read_control_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn read_control_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of read_control.
#Errors
If the returned value contains an invalid bit pattern for read_control. (std) The right to read the information in the object’s security descriptor, not including the information in the system access control list (SACL).
Sourcepub fn with_read_control(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_read_control(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of read_control set to the given value.
#Panics
If the given value is out of bounds for read_control. (std) The right to read the information in the object’s security descriptor, not including the information in the system access control list (SACL).
Sourcepub fn with_read_control_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_read_control_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of read_control set to the given value.
#Errors
If the given value is out of bounds for read_control. (std) The right to read the information in the object’s security descriptor, not including the information in the system access control list (SACL).
Sourcepub fn set_read_control(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_read_control(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of read_control to the given value.
#Panics
If the given value is out of bounds for read_control. (std) The right to read the information in the object’s security descriptor, not including the information in the system access control list (SACL).
Sourcepub fn set_read_control_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_read_control_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of read_control to the given value.
#Errors
If the given value is out of bounds for read_control. (std) The right to read the information in the object’s security descriptor, not including the information in the system access control list (SACL).
Sourcepub fn write_dacl(&self) -> <bool as Specifier>::InOut
pub fn write_dacl(&self) -> <bool as Specifier>::InOut
Returns the value of write_dacl. (std) The right to modify the discretionary access control list (DACL) in the object’s security descriptor.
Sourcepub fn write_dacl_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn write_dacl_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of write_dacl.
#Errors
If the returned value contains an invalid bit pattern for write_dacl. (std) The right to modify the discretionary access control list (DACL) in the object’s security descriptor.
Sourcepub fn with_write_dacl(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_write_dacl(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of write_dacl set to the given value.
#Panics
If the given value is out of bounds for write_dacl. (std) The right to modify the discretionary access control list (DACL) in the object’s security descriptor.
Sourcepub fn with_write_dacl_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_write_dacl_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of write_dacl set to the given value.
#Errors
If the given value is out of bounds for write_dacl. (std) The right to modify the discretionary access control list (DACL) in the object’s security descriptor.
Sourcepub fn set_write_dacl(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_write_dacl(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of write_dacl to the given value.
#Panics
If the given value is out of bounds for write_dacl. (std) The right to modify the discretionary access control list (DACL) in the object’s security descriptor.
Sourcepub fn set_write_dacl_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_write_dacl_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of write_dacl to the given value.
#Errors
If the given value is out of bounds for write_dacl. (std) The right to modify the discretionary access control list (DACL) in the object’s security descriptor.
Sourcepub fn write_owner(&self) -> <bool as Specifier>::InOut
pub fn write_owner(&self) -> <bool as Specifier>::InOut
Returns the value of write_owner. (std) The right to change the owner in the security descriptor for the object.
Sourcepub fn write_owner_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn write_owner_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of write_owner.
#Errors
If the returned value contains an invalid bit pattern for write_owner. (std) The right to change the owner in the security descriptor for the object.
Sourcepub fn with_write_owner(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_write_owner(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of write_owner set to the given value.
#Panics
If the given value is out of bounds for write_owner. (std) The right to change the owner in the security descriptor for the object.
Sourcepub fn with_write_owner_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_write_owner_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of write_owner set to the given value.
#Errors
If the given value is out of bounds for write_owner. (std) The right to change the owner in the security descriptor for the object.
Sourcepub fn set_write_owner(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_write_owner(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of write_owner to the given value.
#Panics
If the given value is out of bounds for write_owner. (std) The right to change the owner in the security descriptor for the object.
Sourcepub fn set_write_owner_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_write_owner_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of write_owner to the given value.
#Errors
If the given value is out of bounds for write_owner. (std) The right to change the owner in the security descriptor for the object.
Sourcepub fn synchronize(&self) -> <bool as Specifier>::InOut
pub fn synchronize(&self) -> <bool as Specifier>::InOut
Returns the value of synchronize. (std) The right to use the object for synchronization. This enables a thread to wait until the object is in the signaled state. Some object types do not support this access right.
Sourcepub fn synchronize_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn synchronize_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of synchronize.
#Errors
If the returned value contains an invalid bit pattern for synchronize. (std) The right to use the object for synchronization. This enables a thread to wait until the object is in the signaled state. Some object types do not support this access right.
Sourcepub fn with_synchronize(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_synchronize(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of synchronize set to the given value.
#Panics
If the given value is out of bounds for synchronize. (std) The right to use the object for synchronization. This enables a thread to wait until the object is in the signaled state. Some object types do not support this access right.
Sourcepub fn with_synchronize_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_synchronize_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of synchronize set to the given value.
#Errors
If the given value is out of bounds for synchronize. (std) The right to use the object for synchronization. This enables a thread to wait until the object is in the signaled state. Some object types do not support this access right.
Sourcepub fn set_synchronize(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_synchronize(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of synchronize to the given value.
#Panics
If the given value is out of bounds for synchronize. (std) The right to use the object for synchronization. This enables a thread to wait until the object is in the signaled state. Some object types do not support this access right.
Sourcepub fn set_synchronize_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_synchronize_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of synchronize to the given value.
#Errors
If the given value is out of bounds for synchronize. (std) The right to use the object for synchronization. This enables a thread to wait until the object is in the signaled state. Some object types do not support this access right.
Sourcepub fn access_system_security(&self) -> <bool as Specifier>::InOut
pub fn access_system_security(&self) -> <bool as Specifier>::InOut
Returns the value of access_system_security. The ability to get or set the SACL in an object’s security descriptor.
Read more on MSDN - SACL Access Right
Sourcepub fn access_system_security_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn access_system_security_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of access_system_security.
#Errors
If the returned value contains an invalid bit pattern for access_system_security. The ability to get or set the SACL in an object’s security descriptor.
Read more on MSDN - SACL Access Right
Sourcepub fn with_access_system_security(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_access_system_security( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of access_system_security set to the given value.
#Panics
If the given value is out of bounds for access_system_security. The ability to get or set the SACL in an object’s security descriptor.
Read more on MSDN - SACL Access Right
Sourcepub fn with_access_system_security_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_access_system_security_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of access_system_security set to the given value.
#Errors
If the given value is out of bounds for access_system_security. The ability to get or set the SACL in an object’s security descriptor.
Read more on MSDN - SACL Access Right
Sourcepub fn set_access_system_security(
&mut self,
new_val: <bool as Specifier>::InOut,
)
pub fn set_access_system_security( &mut self, new_val: <bool as Specifier>::InOut, )
Sets the value of access_system_security to the given value.
#Panics
If the given value is out of bounds for access_system_security. The ability to get or set the SACL in an object’s security descriptor.
Read more on MSDN - SACL Access Right
Sourcepub fn set_access_system_security_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_access_system_security_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of access_system_security to the given value.
#Errors
If the given value is out of bounds for access_system_security. The ability to get or set the SACL in an object’s security descriptor.
Read more on MSDN - SACL Access Right
Sourcepub fn maximum_allowed(&self) -> <bool as Specifier>::InOut
pub fn maximum_allowed(&self) -> <bool as Specifier>::InOut
Returns the value of maximum_allowed. When requesting access, indicates that the caller wants maximum access rights.
Read more on MSDN - Requesting Access Rights to an Object
Sourcepub fn maximum_allowed_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn maximum_allowed_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of maximum_allowed.
#Errors
If the returned value contains an invalid bit pattern for maximum_allowed. When requesting access, indicates that the caller wants maximum access rights.
Read more on MSDN - Requesting Access Rights to an Object
Sourcepub fn with_maximum_allowed(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_maximum_allowed(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of maximum_allowed set to the given value.
#Panics
If the given value is out of bounds for maximum_allowed. When requesting access, indicates that the caller wants maximum access rights.
Read more on MSDN - Requesting Access Rights to an Object
Sourcepub fn with_maximum_allowed_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_maximum_allowed_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of maximum_allowed set to the given value.
#Errors
If the given value is out of bounds for maximum_allowed. When requesting access, indicates that the caller wants maximum access rights.
Read more on MSDN - Requesting Access Rights to an Object
Sourcepub fn set_maximum_allowed(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_maximum_allowed(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of maximum_allowed to the given value.
#Panics
If the given value is out of bounds for maximum_allowed. When requesting access, indicates that the caller wants maximum access rights.
Read more on MSDN - Requesting Access Rights to an Object
Sourcepub fn set_maximum_allowed_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_maximum_allowed_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of maximum_allowed to the given value.
#Errors
If the given value is out of bounds for maximum_allowed. When requesting access, indicates that the caller wants maximum access rights.
Read more on MSDN - Requesting Access Rights to an Object
Sourcepub fn generic_all(&self) -> <bool as Specifier>::InOut
pub fn generic_all(&self) -> <bool as Specifier>::InOut
Returns the value of generic_all. (generic) All possible access rights
Sourcepub fn generic_all_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn generic_all_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of generic_all.
#Errors
If the returned value contains an invalid bit pattern for generic_all. (generic) All possible access rights
Sourcepub fn with_generic_all(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_generic_all(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of generic_all set to the given value.
#Panics
If the given value is out of bounds for generic_all. (generic) All possible access rights
Sourcepub fn with_generic_all_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_generic_all_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of generic_all set to the given value.
#Errors
If the given value is out of bounds for generic_all. (generic) All possible access rights
Sourcepub fn set_generic_all(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_generic_all(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of generic_all to the given value.
#Panics
If the given value is out of bounds for generic_all. (generic) All possible access rights
Sourcepub fn set_generic_all_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_generic_all_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of generic_all to the given value.
#Errors
If the given value is out of bounds for generic_all. (generic) All possible access rights
Sourcepub fn generic_execute(&self) -> <bool as Specifier>::InOut
pub fn generic_execute(&self) -> <bool as Specifier>::InOut
Returns the value of generic_execute. (generic) Execute access
Sourcepub fn generic_execute_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn generic_execute_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of generic_execute.
#Errors
If the returned value contains an invalid bit pattern for generic_execute. (generic) Execute access
Sourcepub fn with_generic_execute(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_generic_execute(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of generic_execute set to the given value.
#Panics
If the given value is out of bounds for generic_execute. (generic) Execute access
Sourcepub fn with_generic_execute_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_generic_execute_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of generic_execute set to the given value.
#Errors
If the given value is out of bounds for generic_execute. (generic) Execute access
Sourcepub fn set_generic_execute(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_generic_execute(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of generic_execute to the given value.
#Panics
If the given value is out of bounds for generic_execute. (generic) Execute access
Sourcepub fn set_generic_execute_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_generic_execute_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of generic_execute to the given value.
#Errors
If the given value is out of bounds for generic_execute. (generic) Execute access
Sourcepub fn generic_write(&self) -> <bool as Specifier>::InOut
pub fn generic_write(&self) -> <bool as Specifier>::InOut
Returns the value of generic_write. (generic) Write access
Sourcepub fn generic_write_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn generic_write_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of generic_write.
#Errors
If the returned value contains an invalid bit pattern for generic_write. (generic) Write access
Sourcepub fn with_generic_write(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_generic_write(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of generic_write set to the given value.
#Panics
If the given value is out of bounds for generic_write. (generic) Write access
Sourcepub fn with_generic_write_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_generic_write_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of generic_write set to the given value.
#Errors
If the given value is out of bounds for generic_write. (generic) Write access
Sourcepub fn set_generic_write(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_generic_write(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of generic_write to the given value.
#Panics
If the given value is out of bounds for generic_write. (generic) Write access
Sourcepub fn set_generic_write_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_generic_write_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of generic_write to the given value.
#Errors
If the given value is out of bounds for generic_write. (generic) Write access
Sourcepub fn generic_read(&self) -> <bool as Specifier>::InOut
pub fn generic_read(&self) -> <bool as Specifier>::InOut
Returns the value of generic_read. (generic) Read access
Sourcepub fn generic_read_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn generic_read_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of generic_read.
#Errors
If the returned value contains an invalid bit pattern for generic_read. (generic) Read access
Sourcepub fn with_generic_read(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_generic_read(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of generic_read set to the given value.
#Panics
If the given value is out of bounds for generic_read. (generic) Read access
Sourcepub fn with_generic_read_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_generic_read_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of generic_read set to the given value.
#Errors
If the given value is out of bounds for generic_read. (generic) Read access
Sourcepub fn set_generic_read(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_generic_read(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of generic_read to the given value.
#Panics
If the given value is out of bounds for generic_read. (generic) Read access
Sourcepub fn set_generic_read_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_generic_read_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of generic_read to the given value.
#Errors
If the given value is out of bounds for generic_read. (generic) Read access