pub struct AceFlags { /* private fields */ }Implementations
Sourceimpl AceFlags
impl AceFlags
Sourcepub const fn into_bytes(self) -> [u8; 1]
pub const fn into_bytes(self) -> [u8; 1]
Sourcepub const fn from_bytes(bytes: [u8; 1]) -> Self
pub const fn from_bytes(bytes: [u8; 1]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl AceFlags
impl AceFlags
Sourcepub fn object_inherit(&self) -> <bool as Specifier>::InOut
pub fn object_inherit(&self) -> <bool as Specifier>::InOut
Returns the value of object_inherit.
Sourcepub fn object_inherit_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn object_inherit_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of object_inherit.
#Errors
If the returned value contains an invalid bit pattern for object_inherit.
Sourcepub fn with_object_inherit(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_object_inherit(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of object_inherit set to the given value.
#Panics
If the given value is out of bounds for object_inherit.
Sourcepub fn with_object_inherit_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_object_inherit_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of object_inherit set to the given value.
#Errors
If the given value is out of bounds for object_inherit.
Sourcepub fn set_object_inherit(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_object_inherit(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of object_inherit to the given value.
#Panics
If the given value is out of bounds for object_inherit.
Sourcepub fn set_object_inherit_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_object_inherit_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of object_inherit to the given value.
#Errors
If the given value is out of bounds for object_inherit.
Sourcepub fn container_inherit(&self) -> <bool as Specifier>::InOut
pub fn container_inherit(&self) -> <bool as Specifier>::InOut
Returns the value of container_inherit.
Sourcepub fn container_inherit_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn container_inherit_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of container_inherit.
#Errors
If the returned value contains an invalid bit pattern for container_inherit.
Sourcepub fn with_container_inherit(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_container_inherit(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of container_inherit set to the given value.
#Panics
If the given value is out of bounds for container_inherit.
Sourcepub fn with_container_inherit_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_container_inherit_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of container_inherit set to the given value.
#Errors
If the given value is out of bounds for container_inherit.
Sourcepub fn set_container_inherit(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_container_inherit(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of container_inherit to the given value.
#Panics
If the given value is out of bounds for container_inherit.
Sourcepub fn set_container_inherit_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_container_inherit_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of container_inherit to the given value.
#Errors
If the given value is out of bounds for container_inherit.
Sourcepub fn no_propagate_inherit(&self) -> <bool as Specifier>::InOut
pub fn no_propagate_inherit(&self) -> <bool as Specifier>::InOut
Returns the value of no_propagate_inherit.
Sourcepub fn no_propagate_inherit_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn no_propagate_inherit_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of no_propagate_inherit.
#Errors
If the returned value contains an invalid bit pattern for no_propagate_inherit.
Sourcepub fn with_no_propagate_inherit(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_no_propagate_inherit( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of no_propagate_inherit set to the given value.
#Panics
If the given value is out of bounds for no_propagate_inherit.
Sourcepub fn with_no_propagate_inherit_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_no_propagate_inherit_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of no_propagate_inherit set to the given value.
#Errors
If the given value is out of bounds for no_propagate_inherit.
Sourcepub fn set_no_propagate_inherit(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_no_propagate_inherit(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of no_propagate_inherit to the given value.
#Panics
If the given value is out of bounds for no_propagate_inherit.
Sourcepub fn set_no_propagate_inherit_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_no_propagate_inherit_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of no_propagate_inherit to the given value.
#Errors
If the given value is out of bounds for no_propagate_inherit.
Sourcepub fn inherit_only(&self) -> <bool as Specifier>::InOut
pub fn inherit_only(&self) -> <bool as Specifier>::InOut
Returns the value of inherit_only.
Sourcepub fn inherit_only_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn inherit_only_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of inherit_only.
#Errors
If the returned value contains an invalid bit pattern for inherit_only.
Sourcepub fn with_inherit_only(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_inherit_only(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of inherit_only set to the given value.
#Panics
If the given value is out of bounds for inherit_only.
Sourcepub fn with_inherit_only_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_inherit_only_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of inherit_only set to the given value.
#Errors
If the given value is out of bounds for inherit_only.
Sourcepub fn set_inherit_only(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_inherit_only(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of inherit_only to the given value.
#Panics
If the given value is out of bounds for inherit_only.
Sourcepub fn set_inherit_only_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_inherit_only_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of inherit_only to the given value.
#Errors
If the given value is out of bounds for inherit_only.
Sourcepub fn inherited_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn inherited_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of inherited.
#Errors
If the returned value contains an invalid bit pattern for inherited.
Sourcepub fn with_inherited(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_inherited(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of inherited set to the given value.
#Panics
If the given value is out of bounds for inherited.
Sourcepub fn with_inherited_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_inherited_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of inherited set to the given value.
#Errors
If the given value is out of bounds for inherited.
Sourcepub fn set_inherited(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_inherited(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of inherited to the given value.
#Panics
If the given value is out of bounds for inherited.
Sourcepub fn set_inherited_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_inherited_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of inherited to the given value.
#Errors
If the given value is out of bounds for inherited.
Sourcepub fn successful_access(&self) -> <bool as Specifier>::InOut
pub fn successful_access(&self) -> <bool as Specifier>::InOut
Returns the value of successful_access.
Sourcepub fn successful_access_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn successful_access_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of successful_access.
#Errors
If the returned value contains an invalid bit pattern for successful_access.
Sourcepub fn with_successful_access(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_successful_access(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of successful_access set to the given value.
#Panics
If the given value is out of bounds for successful_access.
Sourcepub fn with_successful_access_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_successful_access_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of successful_access set to the given value.
#Errors
If the given value is out of bounds for successful_access.
Sourcepub fn set_successful_access(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_successful_access(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of successful_access to the given value.
#Panics
If the given value is out of bounds for successful_access.
Sourcepub fn set_successful_access_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_successful_access_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of successful_access to the given value.
#Errors
If the given value is out of bounds for successful_access.
Sourcepub fn failed_access(&self) -> <bool as Specifier>::InOut
pub fn failed_access(&self) -> <bool as Specifier>::InOut
Returns the value of failed_access.
Sourcepub fn failed_access_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn failed_access_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of failed_access.
#Errors
If the returned value contains an invalid bit pattern for failed_access.
Sourcepub fn with_failed_access(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_failed_access(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of failed_access set to the given value.
#Panics
If the given value is out of bounds for failed_access.
Sourcepub fn with_failed_access_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_failed_access_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of failed_access set to the given value.
#Errors
If the given value is out of bounds for failed_access.
Sourcepub fn set_failed_access(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_failed_access(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of failed_access to the given value.
#Panics
If the given value is out of bounds for failed_access.
Sourcepub fn set_failed_access_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_failed_access_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of failed_access to the given value.
#Errors
If the given value is out of bounds for failed_access.