pub struct ACL {
pub acl_revision: AclRevision,
pub ace: Vec<ACE>,
}Fields
acl_revision: AclRevisionace: Vec<ACE>Implementations
Sourceimpl ACL
impl ACL
Sourcepub fn order_aces(&mut self)
pub fn order_aces(&mut self)
Orders the ACEs in the ACL according to the standard order.
Note that since we do not have sufficient information about the inheritance, we only apply order which is independent of inheritance.
The following steps describe the preferred order:
- ✅ All explicit ACEs are placed in a group before any inherited ACEs.
- ✅ Within the group of explicit ACEs, access-denied ACEs are placed before access-allowed ACEs.
- ❌ Inherited ACEs are placed in the order in which they are inherited. ACEs inherited from the child object’s parent come first, then ACEs inherited from the grandparent, and so on up the tree of objects.
- ❌ For each level of inherited ACEs, access-denied ACEs are placed before access-allowed ACEs.
See more information on Order of ACEs in a DACL - MSDN
Sourcepub fn is_ace_sorted(&self) -> bool
pub fn is_ace_sorted(&self) -> bool
Whether ACE ordering rules apply to this ACL.
See order_aces for the ordering rules.
Sourcepub fn insert_ace(&mut self, ace: ACE)
pub fn insert_ace(&mut self, ace: ACE)
Insert an ACE into the ACL, maintaining the correct order.
See order_aces for the ordering rules.