pub struct SecurityDescriptorControl { /* private fields */ }Implementations
Sourceimpl SecurityDescriptorControl
impl SecurityDescriptorControl
Sourcepub const fn into_bytes(self) -> [u8; 2]
pub const fn into_bytes(self) -> [u8; 2]
Sourcepub const fn from_bytes(bytes: [u8; 2]) -> Self
pub const fn from_bytes(bytes: [u8; 2]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl SecurityDescriptorControl
impl SecurityDescriptorControl
Sourcepub fn owner_defaulted(&self) -> <bool as Specifier>::InOut
pub fn owner_defaulted(&self) -> <bool as Specifier>::InOut
Returns the value of owner_defaulted.
Sourcepub fn owner_defaulted_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn owner_defaulted_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of owner_defaulted.
#Errors
If the returned value contains an invalid bit pattern for owner_defaulted.
Sourcepub fn with_owner_defaulted(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_owner_defaulted(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of owner_defaulted set to the given value.
#Panics
If the given value is out of bounds for owner_defaulted.
Sourcepub fn with_owner_defaulted_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_owner_defaulted_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of owner_defaulted set to the given value.
#Errors
If the given value is out of bounds for owner_defaulted.
Sourcepub fn set_owner_defaulted(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_owner_defaulted(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of owner_defaulted to the given value.
#Panics
If the given value is out of bounds for owner_defaulted.
Sourcepub fn set_owner_defaulted_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_owner_defaulted_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of owner_defaulted to the given value.
#Errors
If the given value is out of bounds for owner_defaulted.
Sourcepub fn group_defaulted(&self) -> <bool as Specifier>::InOut
pub fn group_defaulted(&self) -> <bool as Specifier>::InOut
Returns the value of group_defaulted.
Sourcepub fn group_defaulted_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn group_defaulted_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of group_defaulted.
#Errors
If the returned value contains an invalid bit pattern for group_defaulted.
Sourcepub fn with_group_defaulted(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_group_defaulted(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of group_defaulted set to the given value.
#Panics
If the given value is out of bounds for group_defaulted.
Sourcepub fn with_group_defaulted_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_group_defaulted_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of group_defaulted set to the given value.
#Errors
If the given value is out of bounds for group_defaulted.
Sourcepub fn set_group_defaulted(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_group_defaulted(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of group_defaulted to the given value.
#Panics
If the given value is out of bounds for group_defaulted.
Sourcepub fn set_group_defaulted_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_group_defaulted_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of group_defaulted to the given value.
#Errors
If the given value is out of bounds for group_defaulted.
Sourcepub fn dacl_present(&self) -> <bool as Specifier>::InOut
pub fn dacl_present(&self) -> <bool as Specifier>::InOut
Returns the value of dacl_present.
Sourcepub fn dacl_present_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn dacl_present_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of dacl_present.
#Errors
If the returned value contains an invalid bit pattern for dacl_present.
Sourcepub fn with_dacl_present(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_dacl_present(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of dacl_present set to the given value.
#Panics
If the given value is out of bounds for dacl_present.
Sourcepub fn with_dacl_present_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_dacl_present_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of dacl_present set to the given value.
#Errors
If the given value is out of bounds for dacl_present.
Sourcepub fn set_dacl_present(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_dacl_present(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of dacl_present to the given value.
#Panics
If the given value is out of bounds for dacl_present.
Sourcepub fn set_dacl_present_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_dacl_present_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of dacl_present to the given value.
#Errors
If the given value is out of bounds for dacl_present.
Sourcepub fn dacl_defaulted(&self) -> <bool as Specifier>::InOut
pub fn dacl_defaulted(&self) -> <bool as Specifier>::InOut
Returns the value of dacl_defaulted.
Sourcepub fn dacl_defaulted_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn dacl_defaulted_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of dacl_defaulted.
#Errors
If the returned value contains an invalid bit pattern for dacl_defaulted.
Sourcepub fn with_dacl_defaulted(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_dacl_defaulted(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of dacl_defaulted set to the given value.
#Panics
If the given value is out of bounds for dacl_defaulted.
Sourcepub fn with_dacl_defaulted_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_dacl_defaulted_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of dacl_defaulted set to the given value.
#Errors
If the given value is out of bounds for dacl_defaulted.
Sourcepub fn set_dacl_defaulted(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_dacl_defaulted(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of dacl_defaulted to the given value.
#Panics
If the given value is out of bounds for dacl_defaulted.
Sourcepub fn set_dacl_defaulted_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_dacl_defaulted_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of dacl_defaulted to the given value.
#Errors
If the given value is out of bounds for dacl_defaulted.
Sourcepub fn sacl_present(&self) -> <bool as Specifier>::InOut
pub fn sacl_present(&self) -> <bool as Specifier>::InOut
Returns the value of sacl_present.
Sourcepub fn sacl_present_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn sacl_present_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of sacl_present.
#Errors
If the returned value contains an invalid bit pattern for sacl_present.
Sourcepub fn with_sacl_present(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_sacl_present(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of sacl_present set to the given value.
#Panics
If the given value is out of bounds for sacl_present.
Sourcepub fn with_sacl_present_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_sacl_present_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of sacl_present set to the given value.
#Errors
If the given value is out of bounds for sacl_present.
Sourcepub fn set_sacl_present(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_sacl_present(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of sacl_present to the given value.
#Panics
If the given value is out of bounds for sacl_present.
Sourcepub fn set_sacl_present_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_sacl_present_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of sacl_present to the given value.
#Errors
If the given value is out of bounds for sacl_present.
Sourcepub fn sacl_defaulted(&self) -> <bool as Specifier>::InOut
pub fn sacl_defaulted(&self) -> <bool as Specifier>::InOut
Returns the value of sacl_defaulted.
Sourcepub fn sacl_defaulted_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn sacl_defaulted_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of sacl_defaulted.
#Errors
If the returned value contains an invalid bit pattern for sacl_defaulted.
Sourcepub fn with_sacl_defaulted(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_sacl_defaulted(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of sacl_defaulted set to the given value.
#Panics
If the given value is out of bounds for sacl_defaulted.
Sourcepub fn with_sacl_defaulted_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_sacl_defaulted_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of sacl_defaulted set to the given value.
#Errors
If the given value is out of bounds for sacl_defaulted.
Sourcepub fn set_sacl_defaulted(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_sacl_defaulted(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of sacl_defaulted to the given value.
#Panics
If the given value is out of bounds for sacl_defaulted.
Sourcepub fn set_sacl_defaulted_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_sacl_defaulted_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of sacl_defaulted to the given value.
#Errors
If the given value is out of bounds for sacl_defaulted.
Sourcepub fn dacl_trusted(&self) -> <bool as Specifier>::InOut
pub fn dacl_trusted(&self) -> <bool as Specifier>::InOut
Returns the value of dacl_trusted.
Sourcepub fn dacl_trusted_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn dacl_trusted_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of dacl_trusted.
#Errors
If the returned value contains an invalid bit pattern for dacl_trusted.
Sourcepub fn with_dacl_trusted(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_dacl_trusted(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of dacl_trusted set to the given value.
#Panics
If the given value is out of bounds for dacl_trusted.
Sourcepub fn with_dacl_trusted_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_dacl_trusted_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of dacl_trusted set to the given value.
#Errors
If the given value is out of bounds for dacl_trusted.
Sourcepub fn set_dacl_trusted(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_dacl_trusted(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of dacl_trusted to the given value.
#Panics
If the given value is out of bounds for dacl_trusted.
Sourcepub fn set_dacl_trusted_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_dacl_trusted_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of dacl_trusted to the given value.
#Errors
If the given value is out of bounds for dacl_trusted.
Sourcepub fn server_security(&self) -> <bool as Specifier>::InOut
pub fn server_security(&self) -> <bool as Specifier>::InOut
Returns the value of server_security.
Sourcepub fn server_security_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn server_security_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of server_security.
#Errors
If the returned value contains an invalid bit pattern for server_security.
Sourcepub fn with_server_security(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_server_security(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of server_security set to the given value.
#Panics
If the given value is out of bounds for server_security.
Sourcepub fn with_server_security_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_server_security_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of server_security set to the given value.
#Errors
If the given value is out of bounds for server_security.
Sourcepub fn set_server_security(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_server_security(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of server_security to the given value.
#Panics
If the given value is out of bounds for server_security.
Sourcepub fn set_server_security_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_server_security_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of server_security to the given value.
#Errors
If the given value is out of bounds for server_security.
Sourcepub fn dacl_computed(&self) -> <bool as Specifier>::InOut
pub fn dacl_computed(&self) -> <bool as Specifier>::InOut
Returns the value of dacl_computed.
Sourcepub fn dacl_computed_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn dacl_computed_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of dacl_computed.
#Errors
If the returned value contains an invalid bit pattern for dacl_computed.
Sourcepub fn with_dacl_computed(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_dacl_computed(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of dacl_computed set to the given value.
#Panics
If the given value is out of bounds for dacl_computed.
Sourcepub fn with_dacl_computed_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_dacl_computed_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of dacl_computed set to the given value.
#Errors
If the given value is out of bounds for dacl_computed.
Sourcepub fn set_dacl_computed(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_dacl_computed(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of dacl_computed to the given value.
#Panics
If the given value is out of bounds for dacl_computed.
Sourcepub fn set_dacl_computed_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_dacl_computed_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of dacl_computed to the given value.
#Errors
If the given value is out of bounds for dacl_computed.
Sourcepub fn sacl_computed(&self) -> <bool as Specifier>::InOut
pub fn sacl_computed(&self) -> <bool as Specifier>::InOut
Returns the value of sacl_computed.
Sourcepub fn sacl_computed_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn sacl_computed_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of sacl_computed.
#Errors
If the returned value contains an invalid bit pattern for sacl_computed.
Sourcepub fn with_sacl_computed(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_sacl_computed(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of sacl_computed set to the given value.
#Panics
If the given value is out of bounds for sacl_computed.
Sourcepub fn with_sacl_computed_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_sacl_computed_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of sacl_computed set to the given value.
#Errors
If the given value is out of bounds for sacl_computed.
Sourcepub fn set_sacl_computed(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_sacl_computed(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of sacl_computed to the given value.
#Panics
If the given value is out of bounds for sacl_computed.
Sourcepub fn set_sacl_computed_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_sacl_computed_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of sacl_computed to the given value.
#Errors
If the given value is out of bounds for sacl_computed.
Sourcepub fn dacl_auto_inherited(&self) -> <bool as Specifier>::InOut
pub fn dacl_auto_inherited(&self) -> <bool as Specifier>::InOut
Returns the value of dacl_auto_inherited.
Sourcepub fn dacl_auto_inherited_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn dacl_auto_inherited_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of dacl_auto_inherited.
#Errors
If the returned value contains an invalid bit pattern for dacl_auto_inherited.
Sourcepub fn with_dacl_auto_inherited(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_dacl_auto_inherited( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of dacl_auto_inherited set to the given value.
#Panics
If the given value is out of bounds for dacl_auto_inherited.
Sourcepub fn with_dacl_auto_inherited_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_dacl_auto_inherited_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of dacl_auto_inherited set to the given value.
#Errors
If the given value is out of bounds for dacl_auto_inherited.
Sourcepub fn set_dacl_auto_inherited(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_dacl_auto_inherited(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of dacl_auto_inherited to the given value.
#Panics
If the given value is out of bounds for dacl_auto_inherited.
Sourcepub fn set_dacl_auto_inherited_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_dacl_auto_inherited_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of dacl_auto_inherited to the given value.
#Errors
If the given value is out of bounds for dacl_auto_inherited.
Sourcepub fn sacl_auto_inherited(&self) -> <bool as Specifier>::InOut
pub fn sacl_auto_inherited(&self) -> <bool as Specifier>::InOut
Returns the value of sacl_auto_inherited.
Sourcepub fn sacl_auto_inherited_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn sacl_auto_inherited_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of sacl_auto_inherited.
#Errors
If the returned value contains an invalid bit pattern for sacl_auto_inherited.
Sourcepub fn with_sacl_auto_inherited(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_sacl_auto_inherited( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of sacl_auto_inherited set to the given value.
#Panics
If the given value is out of bounds for sacl_auto_inherited.
Sourcepub fn with_sacl_auto_inherited_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_sacl_auto_inherited_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of sacl_auto_inherited set to the given value.
#Errors
If the given value is out of bounds for sacl_auto_inherited.
Sourcepub fn set_sacl_auto_inherited(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_sacl_auto_inherited(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of sacl_auto_inherited to the given value.
#Panics
If the given value is out of bounds for sacl_auto_inherited.
Sourcepub fn set_sacl_auto_inherited_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_sacl_auto_inherited_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of sacl_auto_inherited to the given value.
#Errors
If the given value is out of bounds for sacl_auto_inherited.
Sourcepub fn dacl_protected(&self) -> <bool as Specifier>::InOut
pub fn dacl_protected(&self) -> <bool as Specifier>::InOut
Returns the value of dacl_protected.
Sourcepub fn dacl_protected_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn dacl_protected_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of dacl_protected.
#Errors
If the returned value contains an invalid bit pattern for dacl_protected.
Sourcepub fn with_dacl_protected(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_dacl_protected(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of dacl_protected set to the given value.
#Panics
If the given value is out of bounds for dacl_protected.
Sourcepub fn with_dacl_protected_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_dacl_protected_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of dacl_protected set to the given value.
#Errors
If the given value is out of bounds for dacl_protected.
Sourcepub fn set_dacl_protected(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_dacl_protected(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of dacl_protected to the given value.
#Panics
If the given value is out of bounds for dacl_protected.
Sourcepub fn set_dacl_protected_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_dacl_protected_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of dacl_protected to the given value.
#Errors
If the given value is out of bounds for dacl_protected.
Sourcepub fn sacl_protected(&self) -> <bool as Specifier>::InOut
pub fn sacl_protected(&self) -> <bool as Specifier>::InOut
Returns the value of sacl_protected.
Sourcepub fn sacl_protected_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn sacl_protected_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of sacl_protected.
#Errors
If the returned value contains an invalid bit pattern for sacl_protected.
Sourcepub fn with_sacl_protected(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_sacl_protected(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of sacl_protected set to the given value.
#Panics
If the given value is out of bounds for sacl_protected.
Sourcepub fn with_sacl_protected_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_sacl_protected_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of sacl_protected set to the given value.
#Errors
If the given value is out of bounds for sacl_protected.
Sourcepub fn set_sacl_protected(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_sacl_protected(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of sacl_protected to the given value.
#Panics
If the given value is out of bounds for sacl_protected.
Sourcepub fn set_sacl_protected_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_sacl_protected_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of sacl_protected to the given value.
#Errors
If the given value is out of bounds for sacl_protected.
Sourcepub fn rm_control_valid(&self) -> <bool as Specifier>::InOut
pub fn rm_control_valid(&self) -> <bool as Specifier>::InOut
Returns the value of rm_control_valid.
Sourcepub fn rm_control_valid_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn rm_control_valid_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of rm_control_valid.
#Errors
If the returned value contains an invalid bit pattern for rm_control_valid.
Sourcepub fn with_rm_control_valid(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_rm_control_valid(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of rm_control_valid set to the given value.
#Panics
If the given value is out of bounds for rm_control_valid.
Sourcepub fn with_rm_control_valid_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_rm_control_valid_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of rm_control_valid set to the given value.
#Errors
If the given value is out of bounds for rm_control_valid.
Sourcepub fn set_rm_control_valid(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_rm_control_valid(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of rm_control_valid to the given value.
#Panics
If the given value is out of bounds for rm_control_valid.
Sourcepub fn set_rm_control_valid_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_rm_control_valid_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of rm_control_valid to the given value.
#Errors
If the given value is out of bounds for rm_control_valid.
Sourcepub fn self_relative(&self) -> <bool as Specifier>::InOut
pub fn self_relative(&self) -> <bool as Specifier>::InOut
Returns the value of self_relative.
Sourcepub fn self_relative_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn self_relative_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of self_relative.
#Errors
If the returned value contains an invalid bit pattern for self_relative.
Sourcepub fn with_self_relative(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_self_relative(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of self_relative set to the given value.
#Panics
If the given value is out of bounds for self_relative.
Sourcepub fn with_self_relative_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_self_relative_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of self_relative set to the given value.
#Errors
If the given value is out of bounds for self_relative.
Sourcepub fn set_self_relative(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_self_relative(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of self_relative to the given value.
#Panics
If the given value is out of bounds for self_relative.
Sourcepub fn set_self_relative_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_self_relative_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of self_relative to the given value.
#Errors
If the given value is out of bounds for self_relative.